@@ -2,6 +2,7 @@
 
 namespace Interop\Http\Factory;
 
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\TestCase;
 use Psr\Http\Message\ResponseFactoryInterface;
 use Psr\Http\Message\ResponseInterface;
@@ -25,23 +26,21 @@ abstract class ResponseFactoryTestCase extends TestCase
 
     protected function assertResponse($response, $code)
     {
-        $this->assertInstanceOf(ResponseInterface::class, $response);
-        $this->assertSame($code, $response->getStatusCode());
+        static::assertInstanceOf(ResponseInterface::class, $response);
+        static::assertSame($code, $response->getStatusCode());
     }
 
-    public function dataCodes()
+    public static function dataCodes()
     {
         return [
-            [200],
-            [301],
-            [404],
-            [500],
+            'HTTP/200' => [200],
+            'HTTP/301' => [301],
+            'HTTP/404' => [404],
+            'HTTP/500' => [500],
         ];
     }
 
-    /**
-     * @dataProvider dataCodes
-     */
+    #[DataProvider('dataCodes')]
     public function testCreateResponse($code)
     {
         $response = $this->factory->createResponse($code);
